// Default.java, created Thu Apr  8 02:22:56 1999 by cananian
// Copyright (C) 1999 C. Scott Ananian <cananian@alumni.princeton.edu>
// Licensed under the terms of the GNU GPL; see COPYING for details.
package harpoon.Util;

import harpoon.Util.Collections.AbstractMapEntry;

import java.util.*;

/**
 * <code>Default</code> contains one-off or 'standard, no-frills'
 * implementations of simple <code>Iterator</code>s,
 * <code>Collection</code>s, and <code>Comparator</code>s.
 * 
 * @author  C. Scott Ananian <cananian@alumni.princeton.edu>
 * @version $Id: Default.java,v 1.6 2003/05/04 02:41:07 cananian Exp $
 */
public abstract class Default  {
    /** A pair constructor method more appropriate for <code>Set</code>
     *  views of <code>Map</code>s and <code>MultiMap</code>s.
     *  The returned object is an instance of <code>Map.Entry</code>;
     *  the only (real) difference from the pairs returned by
     *  <code>Default.pair()</code> is the definition of
     *  <code>hashCode()</code>, which corresponds to <code>Map.Entry</code>
     *  (being <code>key.hashCode() ^ value.hashCode()</code> ) rather
     *  than <code>List</code> (which would be 
     *  <code>31*(31+key.hashCode())+value.hashCode()</code> ). This is
     *  an annoying distinction; I wish the JDK API authors had made
     *  these consistent. The <code>Map.Entry</code> returned is immutable.
     */
    public static <K,V> Map.Entry<K,V> entry(final K key, final V value) {
	return new AbstractMapEntry<K,V>() {
		public K getKey() { return key; }
		public V getValue() { return value; }
	    };
    }
}
